@@ -416,3 +416,42 @@ class TestPersister(persistence.Persister):
 
     def delete_process_checkpoints(self, pid):
         raise NotImplementedError
+
+
+def run_until_waiting(proc):
+    """ Set up a future that will be resolved on entering the WAITING state """
+    from plumpy import ProcessState
+
+    listener = plumpy.ProcessListener()
+    in_waiting = plumpy.Future()
+
+    if proc.state == ProcessState.WAITING:
+        in_waiting.set_result(True)
+    else:
+        def on_waiting(waiting_proc):
+            in_waiting.set_result(True)
+            proc.remove_process_listener(listener)
+
+        listener.on_process_waiting = on_waiting
+        proc.add_process_listener(listener)
+
+    return in_waiting
+
+
+def run_until_paused(proc):
+    """ Set up a future that will be resolved when the process is paused """
+
+    listener = plumpy.ProcessListener()
+    paused = plumpy.Future()
+
+    if proc.paused:
+        paused.set_result(True)
+    else:
+        def on_paused(_paused_proc):
+            paused.set_result(True)
+            proc.remove_process_listener(listener)
+
+        listener.on_process_paused = on_paused
+        proc.add_process_listener(listener)
+
+    return paused
